@@ -1,6 +1,6 @@
 use crate::types::{Guild, User};
 
-#[derive(Serialize, Deserialize)]
+#[derive(Serialize, Deserialize, Clone)]
 pub struct Member {
     pub user_id: Option<u128>,
     pub user: Option<User>,
